"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SqsConsumer = require("sqs-consumer");
const LogManager_1 = require("../log/LogManager");
const log = LogManager_1.LogManager.getLogger();
const defaultAwsRegion = 'ap-southeast-2';
class SqsHandler {
}
exports.SqsHandler = SqsHandler;
class SqsWorker {
    constructor(configuration, name) {
        this.maxRetries = 5;
        this.name = name;
        this.configuration = Object.assign({}, {
            attributeNames: ['All', 'ApproximateFirstReceiveTimestamp', 'ApproximateReceiveCount'],
            region: defaultAwsRegion,
        }, configuration);
        this.consumerCreator = (config) => SqsConsumer.create(config);
    }
    initialise() {
        const conf = Object.assign({}, this.configuration, {
            handleMessage: (m, d) => {
                try {
                    if (m.Attributes.ApproximateReceiveCount > this.getMaxRetries()) {
                        log.error({ m }, `SQS error`);
                        d();
                    }
                    else {
                        this.handler.handle(m, d);
                    }
                }
                catch (err) {
                    d(err);
                }
            },
        });
        this.instance = this.consumerCreator(conf);
        this.instance.on('error', (err) => {
            log.error({ err }, `SQS error`);
        });
        this.instance.start();
    }
    shutdown() {
        this.instance.stop();
    }
    getMaxRetries() {
        return this.maxRetries;
    }
}
SqsWorker.startMethod = 'initialise';
SqsWorker.stopMethod = 'shutdown';
exports.SqsWorker = SqsWorker;
//# sourceMappingURL=SqsWorker.js.map